@@ -104,12 +104,7 @@ class CommonBrowserView(BrowserView):
         return structure
     
     def getLeadMediaTag(self, item, scale="large"):
-        if item.portal_type == "Collection":
-            media = self.getCollectionMedia()
-            lead = None
-            if len(media) > 0:
-                lead = media[0]
-        elif hasattr(item, 'leadMedia'):
+        if hasattr(item, 'leadMedia'):
             lead = item.leadMedia
         else:
             catalog = getToolByName(self.context, 'portal_catalog')
@@ -124,30 +119,6 @@ class CommonBrowserView(BrowserView):
         else:
             return ""
 
-    def getCollectionMedia(self, item):
-        results = []
-        if item.portal_type == "Collection":
-            if hasattr(item, 'getObject'):
-                obj = item.getObject()
-            else:
-                obj = item
-                
-            results = obj.queryCatalog()
-                
-            resultArray = []
-            for res in results:
-                if res.portal_type == "Image":
-                    resultArray.append(res)
-                elif res.portal_type == "Link" and (res.getRemoteUrl.find("youtube.com") > -1 or res.getRemoteUrl.find("vimeo.com") > -1):
-                    resultArray.append(res)
-                else:
-                    if res.hasMedia:
-                        resultArray.append(res.leadMedia)
-            
-            return resultArray
-        else:
-            return results
-
     def containsMedia(self, item):
         if item.portal_type == "Collection":
             return len(self.getCollectionMedia(item)) > 0
